/**************************************************************
	Exercise Set #2
	SGPLOT 

	Grouping, Legends and Axes

**************************************************************/

/*
	SGPLOT Exercise #2.1

	Using the CATEGORY option
*/

title1 "#2.1: CATEGORY option";
title2 "Number of Employees by Sector";

proc sgplot data=fortune;
*	hbox employees / <keyword>=sector;
	hbox employees / <keyword>=sector;
run;

/*
	SGPLOT Exercise #2.2

	LOESS plot 
	Y=mpg_city vs X=msrp GROUPed by Cylinders
	Use LOG x-axis

	What is LOESS?
	The loess procedure fits simple models to localized subsets 
	of the data to plot a smooth curve through a set of data points. 
	The SAS documentation says that it "fits nonparametric models using 
	a local regression method. [The related] PROC LOESS is suitable for 
	modeling regression surfaces where the underlying parametric form is 
	unknown and where robustness in the presence of outliers is required.
*/

title1 "#2.2: LOESS plot with GROUP option";
title "City MPG vs MSRP by # of Cylinders";

proc sgplot data=cars2;
*	loess x=msrp y=mpg_city / <keyword>=cylinders;
	loess x=msrp y=mpg_city / <keyword>=cylinders ;
	xaxis type=log;
run;

/*
	SGPLOT Exercise #2.3

	Multiple statements
*/

title1 "#2.3: 3 SERIES Plots";
title2 "IBM Stock Prices by Date";

proc sgplot data=ibm_stocks ;
	series x=date y=close ;
	series x=date y=low ;
	series x=date y=high;
run;

/* 
	Example #2.4
	Overlaying plot
	The order matters. Series then band doesn't work.
*/

title1 "#2.4: SERIES & BAND Plot";
title2 "IBM Stock Prices by Date";

proc sgplot data=ibm_stocks;
	series x=date y=close ;
	band x=date lower=low upper=high;
run;

/* 
	Example #2.5
	Overlaying plots
	Band then series does. Can work to your advantage. 
*/

title1 "#2.5: Order Matters";
title2 "IBM  Prices by Date";

proc sgplot data=ibm_stocks;
	band x=date lower=low upper=high;
  	series x=date y=close ;
run;

/*
	NB: Back to slides. If the instructor forgets (and he's like that), please let him know.
*/

/*
	SGPLOT Exercise #2.6

	Legends

	KEYLEGEND
	TITLE
	LOCATION

	YAXIS LABEL
*/

title1 "#2.6: Creating Legends";
title2 "IBM Stock Prices by Date";

proc sgplot data=ibm_stocks ;
	series x=date y=close / name="close";
	series x=date y=low / name="low";
	series x=date y=high / name="high";
*	<keyword> "low" "high" / <keyword>="IBM" <keyword>=inside;
	<keyword> "low" "high" / <keyword>="IBM" <keyword>=inside;
*	<keyword> <keyword>="Price";
	<keyword> <keyword>="Price";
run;

/*
	SGPLOT Exercise #2.7

	HBAR type => Horizontal Bar Chart each bar represents a vehicle type
	RESPONSE=invoice => Height of the bar is based on variable invoice
	
	Add 

	GROUP=cylinders => show stacked barchart categories defined by variable cylinders
	GROUPDISPLAY=cluster => change from stacked barchart to side-by-side grouped
	GROUPORDER=ascending => change order of cylinders (GROUP variable) to 4 6 8.
	NOFILL
	NOSTATLABEL
	NOOUTLINE
*/

title1 "#2.7: Grouped Bar Charts";
title2 "Total Invoice Dollars by Type";

proc sgplot data=cars;
	hbar type / response=invoice;
run;

/*
	SGPLOT Exercise #2.8

	Add 

	/  <== don't forget this
	GROUP=type 
	GROUPDISPLAY=cluster 
	CLUSTERWIDTH=0.5 
*/

title1 "#2.8: Grouped Scatter Plot";
title2 "Revenue by Hub";

proc sgplot data=sashelp.revhub2;
  scatter x=hub y=revenue ;
  xaxis type=discrete;
run;

/*
	SGPLOT Exercise #2.9

	Change the CATEGORYORDER to be ascending in the value of the response.
		(9.3 or later)

*/

title1 "#2.9: Ascending Bar Chart Categories";
title2 "Employees by Sector";

proc sgplot data=fortune;
*	hbar sector / RESPONSE=employees <keyword>=respasc;
	hbar sector / RESPONSE=employees <keyword>=respasc;
run;

/*
	SGPLOT Exercise #2.10a

	http://blogs.sas.com/content/graphicallyspeaking/2012/05/03/graphs-with-log-axis/

	VBAR chart 
	GROUPed by ethnicity
	CLUSTER the display of the groups
	Add a DATALABEL on top
	Set the order of the bars in the group to be according to the DATA
	Use a LOG axis for stage
	Use (NOLABEL) for either axis and NOTICKS for the X-axis
	Put the legend as 1 column in the TOPLEFT corner on the INSIDE of the graph
*/

title1 'Ex #2.10a: Barcharts and Log Axis';
title2 'OE Breast Cancer Stages by Ethnicity';

proc sgplot data=oeb_grp;
  format stage 4.1;
*  <keyword> type / response=stage <keyword>=ethnicity groupdisplay=cluster <keyword>
          clusterwidth=0.6 grouporder=<keyword>;
  <keyword> type / response=stage <keyword>=ethnicity groupdisplay=cluster <keyword>
          clusterwidth=0.6 grouporder=<keyword>;
*  yaxis type=<keyword> logbase=2 max=4 offsetmin=0 grid display=(<keyword>);
  yaxis type=<keyword> logbase=2 max=4 offsetmin=0 grid display=(<keyword>);
*  xaxis display=(<keyword> <keyword>);
  xaxis display=(<keyword> <keyword>);
*  keylegend / location=<keyword> position=<keyword> across=<keyword> noborder;
  keylegend / location=<keyword> position=<keyword> across=<keyword> noborder;
  run;

/*
	SGPLOT Exercise #2.10b

	Use HIGHLOW plot so that we can have LOG YAXIS.
  	Set X to TYPE, the LOW value to min (a variable) and 
  	the HIGH value to the response, i.e. stage
  	The TYPE of the highlow plot should be BAR
  	Let's also label the high data point withe its value, i.e. STAGE
  	
*/

title1 'Ex #2.10b: HighLow plot and Log Axis';
title2 'OE Breast Cancer Stages by Ethnicity';

proc sgplot data=oeb_grp;
  format stage 4.1;
*  <keyword> <keyword>=type <keyword>=min <keyword>=stage / group=ethnicity groupdisplay=cluster
          type=<keyword> highlabel=<keyword> clusterwidth=0.6 lineattrs=(color=grey pattern=solid);
  <keyword> <keyword>=type <keyword>=min <keyword>=stage / group=ethnicity groupdisplay=cluster
          type=<keyword> highlabel=<keyword> clusterwidth=0.6 lineattrs=(color=grey pattern=solid);
  yaxis type=log logbase=2 max=4 offsetmin=0 grid display=(nolabel);
  xaxis display=(nolabel noticks);
  keylegend / location=inside position=topleft across=1 noborder;
  run;

/*
	SGPLOT Exercise #2.10c

  	To do it this way, we had to change the structure of the data from tall to wide.

	We'll use 3 DOT plots.
	We'll change the DISCRETEOFFSET for each so that they don't fall
		on top of one another
	Let's also remove the statistics label, so that there is NOSTATLABEL
*/

title1 'Ex #2.10c: Dot Plots and Log Axis';
title2 'OE Breast Cancer Stages by Ethnicity';

proc sgplot data=oeb_multi;
  format white black hispanic 4.1;
*  <keyword> type / response=white <keyword>=-0.2 <keyword>;
  <keyword> type / response=white <keyword>=-0.2 <keyword>;
*  dot type / response=black <keyword>= 0.0 nostatlabel;
  dot type / response=black <keyword>= 0.0 nostatlabel;
*  dot type / response=hispanic <keyword>= 0.2 nostatlabel;
  dot type / response=hispanic <keyword>= 0.2 nostatlabel;
  xaxis type=log logbase=2 logstyle=linear min=1 max=4 grid display=(nolabel);
  yaxis display=(nolabel noticks) offsetmin=0.2 offsetmax=0.2;
  keylegend / title='Ethnicity:';
  run;

/*
	SGPLOT Exercise #2.10d

  	We'll add a REFLINE with a wide THICKNESS and a LIGHTGRAY color so that it
  		separates the ethnicities better.
  	We'll also change the MARKERATTRS to have a CIRCLEFILLED symbol and a large SIZE.
  		That will help us see the markers better.

  */

title1 'Ex #2.10d: Dot Plots and Log Axis';
title2 'OE Breast Cancer Stages by Ethnicity';

proc sgplot data=oeb_multi;
  format white black hispanic 4.1;
*  <keyword> ref / lineattrs=(<keyword>=100 color=<keyword>) transparency=0.6;
  <keyword> ref / lineattrs=(<keyword>=100 color=<keyword>) transparency=0.6;
*  dot type / response=white discreteoffset=-0.2 nostatlabel
             <keyword>=(symbol=<keyword> <keyword>=11) ;
  dot type / response=white discreteoffset=-0.2 nostatlabel
             <keyword>=(symbol=<keyword> <keyword>=11) ;
*  dot type / response=black discreteoffset= 0.0 nostatlabel
             markerattrs=(symbol=circlefilled size=11);
  dot type / response=black discreteoffset= 0.0 nostatlabel
             markerattrs=(symbol=circlefilled size=11);
*  dot type / response=hispanic discreteoffset= 0.2 nostatlabel
             markerattrs=(symbol=circlefilled size=11);
  dot type / response=hispanic discreteoffset= 0.2 nostatlabel
             markerattrs=(symbol=circlefilled size=11);
  xaxis type=log logbase=2 logstyle=linear min=1 max=4.1 grid display=(nolabel)
        offsetmin=0 offsetmax=0;
  yaxis display=(nolabel noticks) offsetmin=0.2 offsetmax=0.2;
  keylegend / title='Ethnicity:';
  run;



