
/*
	Create data sets to be used in HOW
*/

%let homedir=C:\HOW\kincaid_Intro Presentation;

/*
	SASHELP.ORSALES => ORSALES -- "Example set 4.sas"
*/

data orsales;
	set sashelp.orsales;
	nquarter = substr(quarter,5);
run;

/*
	SASHELP.CARS => CARS -- "Example set 4.sas"
*/

data cars;
	set sashelp.cars(where=(make in ("Audi", "BMW")));
run;

data cars2;
	set sashelp.cars(where=(cylinders in (4, 6, 8)));
run;

proc format;
	value cyl_fmt
		4 = '4 Cylinder'
		6 = '6 Cylinder'
		8 = '8 Cylinder'
		;
run;

/*
	CARS => CARS_MISS -- Example set 4.sas
*/

data cars_miss;
	set cars;
	if ((make = "Audi") and (cylinders=8)) then do;
		cylinders = .;
	end;
run;

/*
	EGGS -- "Exercise set 2.sas" and "Exercise set 4.sas"
*/

data fortune;
	infile "&homedir.\data\fortune500_data.txt" dsd;
	length Company $ 32 sector $ 15;
	input Company $ Assets Sales Market_Value Profits Cash_Flow Employees sector $;
run;

data fortune2;
	set fortune(where=(sector ne "Other"));
run;
	

/*
	EGGS -- "Exercise set 4.sas"
*/

data eggs;
	length Lab $ 3;
	infile "&homedir.\data\eggs_dat.txt" dsd;
	label Fat_Content="Fat Content Residuals";
	input Fat_Content Lab $ Technician Sample $;
run;

proc sort data=eggs;
	by lab;
run;

proc means data=eggs noprint;
	by lab;
	var fat_content;
	output out=stat_temp median=statout;
run;

proc sort data=stat_temp;
	by descending statout;
run;

data stat_fmt stat_temp(rename=(label=lab start=labn));
	set stat_temp(keep=lab statout);
	by descending statout;
	start = _N_;
	rename lab=label;
	fmtname = "stat_fmt";
	type = "n";
run;

proc format cntlin=stat_fmt;
run;

proc sort data=stat_temp(keep=lab labn);
	by lab;
run;

proc sort data=eggs;
	by lab;
run;

data eggs;
	merge eggs stat_temp;
	by lab;
	label labn="Laboratory";
	format labn stat_fmt.;
run;


/* 
	Preparing data set for Ellipse Examples.
	Example set 2.sas Example #6
	Moving vertical to horizontal
*/

data ibm intel msft;
	set sashelp.stocks;
	if (stock = "IBM") then do;
		ibm_high = high;
		ibm_vol = volume;
		output ibm;
	end;
	else if (stock = "Intel") then do;
		intel_high = high;
		intel_vol = volume;
		output intel;
	end;
	else do;
		msft_high = high;
		msft_vol = volume;
		output msft;
	end;
run;

proc sort data=ibm;
	by date;
run;

proc sort data=intel;
	by date;
run;

proc sort data=msft;
	by date;
run;

data sbs_stocks;
	merge ibm(keep=ibm_vol ibm_high date) intel(keep=intel_vol intel_high date) 
			msft(keep=msft_vol msft_high date);
	by date;
run;

data ibm_stocks;
	set sashelp.stocks;
	if (stock = "IBM");
run;


data pe_data;
   label pe10="Price-Earnings Ratio";
   infile "&homedir.\data\pe_data.txt";
   input year re pe re10 pe10 label;
run;

data oeb_grp;
	input type $ 1-6 stage ethnicity $;
	min = 1;
	datalines;
Type 1 2.1 White
Type 1 2.4 Black
Type 1 3.8 Hispanic
Type 2 1.8 White
Type 2 1.2 Black
Type 2 2.8 Hispanic
Type 3 2.3 White
Type 3 3.4 Black
Type 3 3.5 Hispanic
;;
run;

/*--OE Brest Cancer Stages Plot--*/
data oeb_multi;
  input type $1-10 White Black Hispanic;
  ref=type;
  if mod(_n_, 2)=1 then ref='';
  min=1;
  WhiteLabel='  White'; BlackLabel='  Black'; HispanicLabel='  Hispanic';
  datalines;
Type 1     2.1   2.4   3.8
Type 2     1.8   1.2   2.8
Type 3     2.3   3.4   3.5
  ;
run;

/*proc print;run;*/
proc template;
  define Style OEB; parent = styles.listing;
    style GraphColors from graphcolors /
          "gdata1"  = cxbfbfbf
          "gdata2"  = cx4f4fff
          "gdata3"  = cx4fcf4f
      ;
  end;
  run;

